@@ -1,5 +1,5 @@
 """
-PyScript is a programming language written in Python. \
+PyScript is a programming language written 100% in Python. \
 This language is not isolated and is directly integrated with the Python's library and namespace levels.
 """
 
@@ -8,18 +8,18 @@ if __import__('sys').version_info < (3, 10):
 
 from . import core
 
-from .core.constants import DEFAULT, DEBUG, SILENT, RETRES, HIGHLIGHT, NO_COLOR, REVERSE_POW_XOR
-from .core.cache import undefined
+from .core.constants import DEFAULT, DEBUG, SILENT, RETURN_RESULT, HIGHLIGHT, NO_COLOR, REVERSE_POW_XOR
+from .core.cache import undefined, hook
 from .core.highlight import HLFMT_HTML, HLFMT_ANSI, HLFMT_BBCODE, pys_highlight, PygmentsPyScriptLexer
 from .core.runner import pys_exec, pys_eval, pys_require, pys_shell
-from .core.version import version_info, __version__, __date__
+from .core.version import version, version_info, __version__, __date__
 
 __all__ = (
     'core',
     'DEFAULT',
     'DEBUG',
     'SILENT',
-    'RETRES',
+    'RETURN_RESULT',
     'HIGHLIGHT',
     'NO_COLOR',
     'REVERSE_POW_XOR',
@@ -27,6 +27,8 @@ __all__ = (
     'HLFMT_ANSI',
     'HLFMT_BBCODE',
     'undefined',
+    'hook',
+    'version',
     'version_info',
     'pys_highlight',
     'pys_exec',
