@@ -1,10 +1,11 @@
 from .bases import Pys
 from .constants import LIBRARIES_PATH, SITE_PACKAGES_PATH
+from .exceptions import PysTraceback
 from .utils.debug import print_display, print_traceback
 from .utils.decorators import inheritable, singleton
 
 from threading import RLock
-from typing import Literal
+from typing import Any, Callable, Literal
 
 loading_modules = set()
 lock = RLock()
@@ -35,7 +36,7 @@ class PysHook(Pys):
 
     __slots__ = ()
 
-    def __new_singleton__(cls):
+    def __new_singleton__(cls) -> 'PysHook':
         global hook
         hook = super(cls, cls).__new__(cls)
         hook.running_shell = False
@@ -46,61 +47,61 @@ class PysHook(Pys):
         hook.ps2 = '... '
         return hook
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f'<hook object at {id(self):016X}>'
 
     @property
-    def running_shell(self):
+    def running_shell(self) -> bool:
         return singletons['hook.running_shell']
 
     @running_shell.setter
-    def running_shell(self, value):
+    def running_shell(self, value: bool) -> None:
         singletons['hook.running_shell'] = bool(value)
 
     @property
-    def running_breakpoint(self):
+    def running_breakpoint(self) -> bool:
         return singletons['hook.running_breakpoint']
 
     @running_breakpoint.setter
-    def running_breakpoint(self, value):
+    def running_breakpoint(self, value: bool) -> None:
         singletons['hook.running_breakpoint'] = bool(value)
 
     @property
-    def display(self):
+    def display(self) -> Callable[[Any], None]:
         return singletons['hook.display']
 
     @display.setter
-    def display(self, value):
+    def display(self, value: Callable[[Any], None]) -> None:
         if value is not None and not callable(value):
             raise TypeError("hook.display: must be callable")
         singletons['hook.display'] = value
 
     @property
-    def exception(self):
+    def exception(self) -> Callable[[type[BaseException], BaseException | None, PysTraceback], None]:
         return singletons['hook.exception']
 
     @exception.setter
-    def exception(self, value):
+    def exception(self, value: Callable[[type[BaseException], BaseException | None, PysTraceback], None]) -> None:
         if value is not None and not callable(value):
             raise TypeError("hook.exception: must be callable")
         singletons['hook.exception'] = value
 
     @property
-    def ps1(self):
+    def ps1(self) -> str:
         return singletons['hook.ps1']
 
     @ps1.setter
-    def ps1(self, value):
+    def ps1(self, value: str) -> None:
         if not isinstance(value, str):
             raise TypeError("hook.ps1: must be a string")
         singletons['hook.ps1'] = value
 
     @property
-    def ps2(self):
+    def ps2(self) -> str:
         return singletons['hook.ps2']
 
     @ps2.setter
-    def ps2(self, value):
+    def ps2(self, value: str) -> None:
         if not isinstance(value, str):
             raise TypeError("hook.ps2: must be a string")
         singletons['hook.ps2'] = value
